<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:csv="csv:csv">
	<xsl:output encoding="UTF-8" indent="yes" version="1.0" method="text"/>
    <xsl:strip-space elements="*" />

    <xsl:variable name="delimiter" select="'|'" />

	<!-- 
		Transformačná šablóna transformuje položky prijatej faktúry do formátu CSV
	-->

    <csv:columns>		
        <column>Number</column>
        <column>BarCode</column>
        <column>Name</column>
        <column>Amount_Unit</column>
        <column>Unit</column>
        <column>Price_WithoutVAT_Unit</column>
        <column>Price_WithVAT_Unit</column>
        <column>Price_WithVAT</column>
        <column>VAT_Rate</column>
    </csv:columns>


    <xsl:template match="/">
        <!-- Output the CSV header -->
        
		<xsl:for-each select="document('')/*/csv:columns/*">
                <xsl:value-of select="."/>
                <xsl:if test="position() != last()">
                    <xsl:value-of select="$delimiter"/>
                </xsl:if>
        </xsl:for-each>
        <xsl:text>&#xa;</xsl:text>

		<xsl:for-each select="//OBERON/Data/InvoicesReceived/Record">
			<xsl:for-each select="Items/Item">

				<xsl:variable name="property" select="." />

				<xsl:for-each select="document('')/*/csv:columns/*">
					<!-- Extract the column name and value -->
					<xsl:variable name="column" select="." />
					<xsl:variable name="value" select="$property/*[name() = $column]" />

					<!-- Quote the value if required -->
					<xsl:choose>
						<xsl:when test="contains($value, '&quot;')">
							<xsl:variable name="x" select="translate($value, '&quot;',  '&quot;&quot;')"/>
							<xsl:value-of select="concat('&quot;', $x, '&quot;')"/>
						</xsl:when>
						<xsl:when test="contains($value, $delimiter)">
							<xsl:value-of select="concat('&quot;', $value, '&quot;')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$value"/>
						</xsl:otherwise>
					</xsl:choose>

					<!-- Add the delimiter unless we are the last expression -->
					<xsl:if test="position() != last()">
						<xsl:value-of select="$delimiter"/>
					</xsl:if>
				</xsl:for-each>

				<!-- Add a newline at the end of the record -->
				<xsl:text>&#xa;</xsl:text>

			</xsl:for-each>
		</xsl:for-each>

    </xsl:template>

</xsl:stylesheet>